package com.srs.comprehensive.mapper;

import java.util.List;

import com.srs.comprehensive.domain.CphScienceScore;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;

/**
 * 学生课程成绩Mapper接口
 *
 * @author srs
 * @date 2024-03-14
 */
public interface CphScienceScoreMapper extends BaseMapper<CphScienceScore> {
    /**
     * 查询学生课程成绩
     *
     * @param id 学生课程成绩主键
     * @return 学生课程成绩
     */
    public CphScienceScore selectCphScienceScoreById(Long id);

    /**
     * 查询学生课程成绩列表
     *
     * @param cphScienceScore 学生课程成绩
     * @return 学生课程成绩集合
     */
    List<CphScienceScore> selectCphScienceScoreList(CphScienceScore cphScienceScore);

    /**
     * 新增学生课程成绩
     *
     * @param cphScienceScore 学生课程成绩
     * @return 结果
     */
    int insertCphScienceScore(CphScienceScore cphScienceScore);

    /**
     * 修改学生课程成绩
     *
     * @param cphScienceScore 学生课程成绩
     * @return 结果
     */
    int updateCphScienceScore(CphScienceScore cphScienceScore);

    /**
     * 删除学生课程成绩
     *
     * @param id 学生课程成绩主键
     * @return 结果
     */
    int deleteCphScienceScoreById(Long id);

    /**
     * 批量删除学生课程成绩
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteCphScienceScoreByIds(Long[] ids);
}
